summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets')
-rw-r--r--kmymoney2/widgets/kaccounttemplateselector.cpp10
-rw-r--r--kmymoney2/widgets/kaccounttemplateselectordecl.cpp4
-rw-r--r--kmymoney2/widgets/kaccounttemplateselectordecl.ui4
-rw-r--r--kmymoney2/widgets/klistviewsearchline.cpp86
-rw-r--r--kmymoney2/widgets/klistviewsearchline.h52
-rw-r--r--kmymoney2/widgets/kmymoneyaccountselector.cpp4
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttree.cpp4
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttree.h14
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebase.cpp28
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebase.h28
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebudget.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebudget.h6
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.h6
-rw-r--r--kmymoney2/widgets/kmymoneycalendar.cpp8
-rw-r--r--kmymoney2/widgets/kmymoneychecklistitem.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneychecklistitem.h4
-rw-r--r--kmymoney2/widgets/kmymoneycompletion.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneycompletion.h6
-rw-r--r--kmymoney2/widgets/kmymoneydateinput.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyforecastlistviewitem.cpp6
-rw-r--r--kmymoney2/widgets/kmymoneyforecastlistviewitem.h4
-rw-r--r--kmymoney2/widgets/kmymoneylistviewitem.cpp8
-rw-r--r--kmymoney2/widgets/kmymoneylistviewitem.h4
-rw-r--r--kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui2
-rw-r--r--kmymoney2/widgets/kmymoneypriceview.cpp8
-rw-r--r--kmymoney2/widgets/kmymoneypriceview.h6
-rw-r--r--kmymoney2/widgets/kmymoneyscheduledcalendar.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyscheduledcalendar.h4
-rw-r--r--kmymoney2/widgets/kmymoneyselector.cpp2
-rw-r--r--kmymoney2/widgets/kmymoneyselector.h14
-rw-r--r--kmymoney2/widgets/registersearchline.h4
-rw-r--r--kmymoney2/widgets/sortoptionlistitem.h8
-rw-r--r--kmymoney2/widgets/transactionsortoption.ui6
-rw-r--r--kmymoney2/widgets/transactionsortoption.ui.h2
35 files changed, 177 insertions, 177 deletions
diff --git a/kmymoney2/widgets/kaccounttemplateselector.cpp b/kmymoney2/widgets/kaccounttemplateselector.cpp
index badcdff..d7afd37 100644
--- a/kmymoney2/widgets/kaccounttemplateselector.cpp
+++ b/kmymoney2/widgets/kaccounttemplateselector.cpp
@@ -38,7 +38,7 @@
#include "kaccounttemplateselector.h"
-class KTemplateListItem : public KListViewItem
+class KTemplateListItem : public TDEListViewItem
{
public:
KTemplateListItem(TQListViewItem* parent, const TQString& text);
@@ -48,7 +48,7 @@ class KTemplateListItem : public KListViewItem
};
KTemplateListItem::KTemplateListItem(TQListViewItem* parent, const TQString& text) :
- KListViewItem(parent, text),
+ TDEListViewItem(parent, text),
m_isAvailable(false)
{
}
@@ -132,7 +132,7 @@ void KAccountTemplateSelector::Private::loadHierarchy(void)
TQRegExp exp("(.*):(.*)");
for(it_m = m_templateHierarchy.begin(); it_m != m_templateHierarchy.end(); ++it_m) {
if(exp.search(it_m.key()) == -1) {
- (*it_m) = new KListViewItem(m_parent->m_accountList, it_m.key());
+ (*it_m) = new TDEListViewItem(m_parent->m_accountList, it_m.key());
} else {
(*it_m) = hierarchyItem(exp.cap(1), exp.cap(2));
}
@@ -233,7 +233,7 @@ void KAccountTemplateSelector::slotLoadCountry(void)
{
#ifndef KMM_DESIGNER
- KListViewItem* parent = new KListViewItem(m_groupList, d->it_m.key());
+ TDEListViewItem* parent = new TDEListViewItem(m_groupList, d->it_m.key());
parent->setSelectable(false);
TQStringList::iterator it;
for(it = d->dirlist.begin(); it != d->dirlist.end(); ++it) {
@@ -244,7 +244,7 @@ void KAccountTemplateSelector::slotLoadCountry(void)
for(it_f = files.begin(); it_f != files.end(); ++it_f) {
MyMoneyTemplate templ(TQString("%1/%2").arg(dir.canonicalPath()).arg(*it_f));
d->m_templates[TQString("%1").arg(d->id)] = templ;
- new KListViewItem(parent, templ.title(), templ.shortDescription(), TQString("%1").arg(d->id));
+ new TDEListViewItem(parent, templ.title(), templ.shortDescription(), TQString("%1").arg(d->id));
++d->id;
}
}
diff --git a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
index c4c683e..80e5c58 100644
--- a/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
+++ b/kmymoney2/widgets/kaccounttemplateselectordecl.cpp
@@ -36,7 +36,7 @@ KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, co
setName( "KAccountTemplateSelectorDecl" );
KAccountTemplateSelectorDeclLayout = new TQVBoxLayout( this, 0, 6, "KAccountTemplateSelectorDeclLayout");
- m_groupList = new KListView( this, "m_groupList" );
+ m_groupList = new TDEListView( this, "m_groupList" );
m_groupList->addColumn( kmm_i18n( "Account Types" ) );
m_groupList->addColumn( kmm_i18n( "Description" ) );
m_groupList->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, m_groupList->sizePolicy().hasHeightForWidth() ) );
@@ -71,7 +71,7 @@ KAccountTemplateSelectorDecl::KAccountTemplateSelectorDecl( TQWidget* parent, co
groupBox2Layout = new TQVBoxLayout( groupBox2->layout() );
groupBox2Layout->setAlignment( TQt::AlignTop );
- m_accountList = new KListView( groupBox2, "m_accountList" );
+ m_accountList = new TDEListView( groupBox2, "m_accountList" );
m_accountList->addColumn( kmm_i18n( "Name" ) );
m_accountList->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 3, m_accountList->sizePolicy().hasHeightForWidth() ) );
m_accountList->setMinimumSize( TQSize( 0, 150 ) );
diff --git a/kmymoney2/widgets/kaccounttemplateselectordecl.ui b/kmymoney2/widgets/kaccounttemplateselectordecl.ui
index cc5b9da..c722c0e 100644
--- a/kmymoney2/widgets/kaccounttemplateselectordecl.ui
+++ b/kmymoney2/widgets/kaccounttemplateselectordecl.ui
@@ -19,7 +19,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Account Types</string>
@@ -136,7 +136,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Name</string>
diff --git a/kmymoney2/widgets/klistviewsearchline.cpp b/kmymoney2/widgets/klistviewsearchline.cpp
index b2d554c..0af29d7 100644
--- a/kmymoney2/widgets/klistviewsearchline.cpp
+++ b/kmymoney2/widgets/klistviewsearchline.cpp
@@ -33,17 +33,17 @@
#define KLISTVIEWSEARCHLINE_ALLVISIBLECOLUMNS_ID 2004
-class KListViewSearchLine::KListViewSearchLinePrivate
+class TDEListViewSearchLine::TDEListViewSearchLinePrivate
{
public:
- KListViewSearchLinePrivate() :
+ TDEListViewSearchLinePrivate() :
listView(0),
caseSensitive(false),
activeSearch(false),
keepParentsVisible(true),
queuedSearches(0) {}
- KListView *listView;
+ TDEListView *listView;
bool caseSensitive;
bool activeSearch;
bool keepParentsVisible;
@@ -56,10 +56,10 @@ public:
// public methods
////////////////////////////////////////////////////////////////////////////////
-KListViewSearchLine::KListViewSearchLine(TQWidget *parent, KListView *listView, const char *name) :
+TDEListViewSearchLine::TDEListViewSearchLine(TQWidget *parent, TDEListView *listView, const char *name) :
KLineEdit(parent, name)
{
- d = new KListViewSearchLinePrivate;
+ d = new TDEListViewSearchLinePrivate;
d->listView = listView;
@@ -79,10 +79,10 @@ KListViewSearchLine::KListViewSearchLine(TQWidget *parent, KListView *listView,
setEnabled(false);
}
-KListViewSearchLine::KListViewSearchLine(TQWidget *parent, const char *name) :
+TDEListViewSearchLine::TDEListViewSearchLine(TQWidget *parent, const char *name) :
KLineEdit(parent, name)
{
- d = new KListViewSearchLinePrivate;
+ d = new TDEListViewSearchLinePrivate;
d->listView = 0;
@@ -92,27 +92,27 @@ KListViewSearchLine::KListViewSearchLine(TQWidget *parent, const char *name) :
setEnabled(false);
}
-KListViewSearchLine::~KListViewSearchLine()
+TDEListViewSearchLine::~TDEListViewSearchLine()
{
delete d;
}
-bool KListViewSearchLine::caseSensitive() const
+bool TDEListViewSearchLine::caseSensitive() const
{
return d->caseSensitive;
}
-TQValueList<int> KListViewSearchLine::searchColumns() const
+TQValueList<int> TDEListViewSearchLine::searchColumns() const
{
return d->searchColumns;
}
-bool KListViewSearchLine::keepParentsVisible() const
+bool TDEListViewSearchLine::keepParentsVisible() const
{
return d->keepParentsVisible;
}
-KListView *KListViewSearchLine::listView() const
+TDEListView *TDEListViewSearchLine::listView() const
{
return d->listView;
}
@@ -121,7 +121,7 @@ KListView *KListViewSearchLine::listView() const
// public slots
////////////////////////////////////////////////////////////////////////////////
-void KListViewSearchLine::updateSearch(const TQString &s)
+void TDEListViewSearchLine::updateSearch(const TQString &s)
{
if(!d->listView)
return;
@@ -135,9 +135,9 @@ void KListViewSearchLine::updateSearch(const TQString &s)
switch(d->listView->selectionMode())
{
- case KListView::NoSelection:
+ case TDEListView::NoSelection:
break;
- case KListView::Single:
+ case TDEListView::Single:
currentItem = d->listView->selectedItem();
break;
default:
@@ -162,22 +162,22 @@ void KListViewSearchLine::updateSearch(const TQString &s)
d->listView->ensureItemVisible(currentItem);
}
-void KListViewSearchLine::setCaseSensitive(bool cs)
+void TDEListViewSearchLine::setCaseSensitive(bool cs)
{
d->caseSensitive = cs;
}
-void KListViewSearchLine::setKeepParentsVisible(bool v)
+void TDEListViewSearchLine::setKeepParentsVisible(bool v)
{
d->keepParentsVisible = v;
}
-void KListViewSearchLine::setSearchColumns(const TQValueList<int> &columns)
+void TDEListViewSearchLine::setSearchColumns(const TQValueList<int> &columns)
{
d->searchColumns = columns;
}
-void KListViewSearchLine::setListView(KListView *lv)
+void TDEListViewSearchLine::setListView(TDEListView *lv)
{
if(d->listView) {
disconnect(d->listView, TQT_SIGNAL(destroyed()),
@@ -208,7 +208,7 @@ void KListViewSearchLine::setListView(KListView *lv)
// protected members
////////////////////////////////////////////////////////////////////////////////
-bool KListViewSearchLine::itemMatches(const TQListViewItem *item, const TQString &s) const
+bool TDEListViewSearchLine::itemMatches(const TQListViewItem *item, const TQString &s) const
{
if(s.isEmpty())
return true;
@@ -237,7 +237,7 @@ bool KListViewSearchLine::itemMatches(const TQListViewItem *item, const TQString
return false;
}
-TQPopupMenu *KListViewSearchLine::createPopupMenu()
+TQPopupMenu *TDEListViewSearchLine::createPopupMenu()
{
TQPopupMenu *popup = KLineEdit::createPopupMenu();
@@ -287,14 +287,14 @@ TQPopupMenu *KListViewSearchLine::createPopupMenu()
// protected slots
////////////////////////////////////////////////////////////////////////////////
-void KListViewSearchLine::queueSearch(const TQString &search)
+void TDEListViewSearchLine::queueSearch(const TQString &search)
{
d->queuedSearches++;
d->search = search;
TQTimer::singleShot(200, this, TQT_SLOT(activateSearch()));
}
-void KListViewSearchLine::activateSearch()
+void TDEListViewSearchLine::activateSearch()
{
--(d->queuedSearches);
@@ -306,18 +306,18 @@ void KListViewSearchLine::activateSearch()
// private slots
////////////////////////////////////////////////////////////////////////////////
-void KListViewSearchLine::itemAdded(TQListViewItem *item) const
+void TDEListViewSearchLine::itemAdded(TQListViewItem *item) const
{
item->setVisible(itemMatches(item, text()));
}
-void KListViewSearchLine::listViewDeleted()
+void TDEListViewSearchLine::listViewDeleted()
{
d->listView = 0;
setEnabled(false);
}
-void KListViewSearchLine::searchColumnsMenuActivated(int id)
+void TDEListViewSearchLine::searchColumnsMenuActivated(int id)
{
if(id == KLISTVIEWSEARCHLINE_ALLVISIBLECOLUMNS_ID) {
if(d->searchColumns.isEmpty())
@@ -346,7 +346,7 @@ void KListViewSearchLine::searchColumnsMenuActivated(int id)
// private methods
////////////////////////////////////////////////////////////////////////////////
-void KListViewSearchLine::checkItemParentsNotVisible()
+void TDEListViewSearchLine::checkItemParentsNotVisible()
{
TQListViewItemIterator it(d->listView);
for(; it.current(); ++it)
@@ -370,7 +370,7 @@ void KListViewSearchLine::checkItemParentsNotVisible()
* \return \c true if an item which should be visible is found, \c false if all items found should be hidden. If this function
* returns true and \p highestHiddenParent was not 0, highestHiddenParent will have been shown.
*/
-bool KListViewSearchLine::checkItemParentsVisible(TQListViewItem *item, TQListViewItem *highestHiddenParent)
+bool TDEListViewSearchLine::checkItemParentsVisible(TQListViewItem *item, TQListViewItem *highestHiddenParent)
{
bool visible = false;
TQListViewItem * first = item;
@@ -409,24 +409,24 @@ bool KListViewSearchLine::checkItemParentsVisible(TQListViewItem *item, TQListVi
}
////////////////////////////////////////////////////////////////////////////////
-// KListViewSearchLineWidget
+// TDEListViewSearchLineWidget
////////////////////////////////////////////////////////////////////////////////
-class KListViewSearchLineWidget::KListViewSearchLineWidgetPrivate
+class TDEListViewSearchLineWidget::TDEListViewSearchLineWidgetPrivate
{
public:
- KListViewSearchLineWidgetPrivate() : listView(0), searchLine(0), clearButton(0) {}
- KListView *listView;
- KListViewSearchLine *searchLine;
+ TDEListViewSearchLineWidgetPrivate() : listView(0), searchLine(0), clearButton(0) {}
+ TDEListView *listView;
+ TDEListViewSearchLine *searchLine;
TQToolButton *clearButton;
};
-KListViewSearchLineWidget::KListViewSearchLineWidget(KListView *listView,
+TDEListViewSearchLineWidget::TDEListViewSearchLineWidget(TDEListView *listView,
TQWidget *parent,
const char *name) :
TQHBox(parent, name)
{
- d = new KListViewSearchLineWidgetPrivate;
+ d = new TDEListViewSearchLineWidgetPrivate;
d->listView = listView;
setSpacing(5);
@@ -434,19 +434,19 @@ KListViewSearchLineWidget::KListViewSearchLineWidget(KListView *listView,
TQTimer::singleShot(0, this, TQT_SLOT(createWidgets()));
}
-KListViewSearchLineWidget::~KListViewSearchLineWidget()
+TDEListViewSearchLineWidget::~TDEListViewSearchLineWidget()
{
delete d;
}
-KListViewSearchLine *KListViewSearchLineWidget::createSearchLine(KListView *listView)
+TDEListViewSearchLine *TDEListViewSearchLineWidget::createSearchLine(TDEListView *listView)
{
if(!d->searchLine)
- d->searchLine = new KListViewSearchLine(this, listView);
+ d->searchLine = new TDEListViewSearchLine(this, listView);
return d->searchLine;
}
-void KListViewSearchLineWidget::createWidgets()
+void TDEListViewSearchLineWidget::createWidgets()
{
positionInToolBar();
@@ -469,14 +469,14 @@ void KListViewSearchLineWidget::createWidgets()
connect(d->clearButton, TQT_SIGNAL(clicked()), d->searchLine, TQT_SLOT(clear()));
}
-KListViewSearchLine *KListViewSearchLineWidget::searchLine() const
+TDEListViewSearchLine *TDEListViewSearchLineWidget::searchLine() const
{
return d->searchLine;
}
-void KListViewSearchLineWidget::positionInToolBar()
+void TDEListViewSearchLineWidget::positionInToolBar()
{
- KToolBar *toolBar = dynamic_cast<KToolBar *>(parent());
+ TDEToolBar *toolBar = dynamic_cast<TDEToolBar *>(parent());
if(toolBar) {
@@ -492,7 +492,7 @@ void KListViewSearchLineWidget::positionInToolBar()
toolBar->setItemAutoSized(id);
if(!d->clearButton) {
TQString icon = TQApplication::reverseLayout() ? "clear_left" : "locationbar_erase";
- d->clearButton = new KToolBarButton(icon, 2005, toolBar);
+ d->clearButton = new TDEToolBarButton(icon, 2005, toolBar);
}
toolBar->insertWidget(2005, d->clearButton->width(), d->clearButton, index);
break;
diff --git a/kmymoney2/widgets/kmymoneyaccountselector.cpp b/kmymoney2/widgets/kmymoneyaccountselector.cpp
index 33bba13..17f8756 100644
--- a/kmymoney2/widgets/kmymoneyaccountselector.cpp
+++ b/kmymoney2/widgets/kmymoneyaccountselector.cpp
@@ -340,7 +340,7 @@ int AccountSet::load(kMyMoneyAccountSelector* selector)
typeMask |= KMyMoneyUtils::equity;
selector->clear();
- KListView* lv = selector->listView();
+ TDEListView* lv = selector->listView();
m_count = 0;
TQString key;
TQListViewItem* after = 0;
@@ -476,7 +476,7 @@ int AccountSet::load(kMyMoneyAccountSelector* selector, const TQString& baseName
++count;
}
- KListView* lv = selector->listView();
+ TDEListView* lv = selector->listView();
if(lv->firstChild()) {
lv->setCurrentItem(lv->firstChild());
lv->clearSelection();
diff --git a/kmymoney2/widgets/kmymoneyaccounttree.cpp b/kmymoney2/widgets/kmymoneyaccounttree.cpp
index c3a9895..1f7c2ae 100644
--- a/kmymoney2/widgets/kmymoneyaccounttree.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttree.cpp
@@ -62,7 +62,7 @@ KMyMoneyAccountTree::KMyMoneyAccountTree(TQWidget* parent, const char *name) :
showValue();
}
-KMyMoneyAccountTreeItem::KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security , const TQString& name) :
+KMyMoneyAccountTreeItem::KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security , const TQString& name) :
KMyMoneyAccountTreeBaseItem(parent,account,security,name),
m_reconcileFlag(false)
{
@@ -76,7 +76,7 @@ KMyMoneyAccountTreeItem::KMyMoneyAccountTreeItem(KMyMoneyAccountTreeBaseItem *pa
updateAccount();
}
-KMyMoneyAccountTreeItem::KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyInstitution& institution) :
+KMyMoneyAccountTreeItem::KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyInstitution& institution) :
KMyMoneyAccountTreeBaseItem(parent,institution),
m_reconcileFlag(false)
{
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
index fa8b5ed..f943d57 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreebase.cpp
@@ -47,7 +47,7 @@
#include <kmymoney/kmymoneyutils.h>
KMyMoneyAccountTreeBase::KMyMoneyAccountTreeBase(TQWidget* parent, const char* name) :
- KListView(parent, name),
+ TDEListView(parent, name),
m_accountConnections(false),
m_institutionConnections(false),
m_queuedSort(0)
@@ -82,7 +82,7 @@ KMyMoneyAccountTreeBase::KMyMoneyAccountTreeBase(TQWidget* parent, const char* n
connect(this, TQT_SIGNAL(dropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)), this, TQT_SLOT(slotObjectDropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)));
connect(this, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(slotSelectObject(TQListViewItem*)));
- connect(this, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem* , const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(KListView*, TQListViewItem*, const TQPoint&)));
+ connect(this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem* , const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&,int)), this, TQT_SLOT(slotOpenObject(TQListViewItem*)));
// drag and drop timer connections
@@ -105,7 +105,7 @@ void KMyMoneyAccountTreeBase::restoreLayout(const TQString& group)
// we use equal distribution of all fields as an initial setting
// TODO this only makes the first column invisible if settings exist setColumnWidth(0, 0);
m_configGroup = group;
- KListView::restoreLayout(TDEGlobal::config(), m_configGroup);
+ TDEListView::restoreLayout(TDEGlobal::config(), m_configGroup);
}
void KMyMoneyAccountTreeBase::showType(void)
@@ -151,7 +151,7 @@ void KMyMoneyAccountTreeBase::setSectionHeader(const TQString& txt)
KMyMoneyAccountTreeBaseItem* KMyMoneyAccountTreeBase::selectedItem(void) const
{
- return dynamic_cast<KMyMoneyAccountTreeBaseItem *>(KListView::selectedItem());
+ return dynamic_cast<KMyMoneyAccountTreeBaseItem *>(TDEListView::selectedItem());
}
const KMyMoneyAccountTreeBaseItem* KMyMoneyAccountTreeBase::findItem(const TQString& id) const
@@ -332,7 +332,7 @@ void KMyMoneyAccountTreeBase::slotSelectObject(TQListViewItem* i)
}
}
-void KMyMoneyAccountTreeBase::slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint&)
+void KMyMoneyAccountTreeBase::slotOpenContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint&)
{
Q_UNUSED(lv);
@@ -533,8 +533,8 @@ const MyMoneyObject& KMyMoneyAccountTreeBaseItem::itemObject(void) const
return m_account;
}
-KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyInstitution& institution) :
- KListViewItem(parent),
+KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(TDEListView *parent, const MyMoneyInstitution& institution) :
+ TDEListViewItem(parent),
m_totalValue(MyMoneyMoney(0)),
m_negative(false),
m_institution(institution),
@@ -543,8 +543,8 @@ KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(KListView *parent, cons
setName();
}
-KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security, const TQString& name) :
- KListViewItem(parent),
+KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security, const TQString& name) :
+ TDEListViewItem(parent),
m_security(security),
m_totalValue(MyMoneyMoney(0)),
m_account(account),
@@ -561,7 +561,7 @@ KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(KListView *parent, cons
}
KMyMoneyAccountTreeBaseItem::KMyMoneyAccountTreeBaseItem(KMyMoneyAccountTreeBaseItem *parent, const MyMoneyAccount& account, const TQValueList<MyMoneyPrice>& price, const MyMoneySecurity& security) :
- KListViewItem(parent),
+ TDEListViewItem(parent),
m_price(price),
m_security(security),
m_totalValue(MyMoneyMoney(0)),
@@ -673,7 +673,7 @@ void KMyMoneyAccountTreeBaseItem::setOpen(bool open)
{
if (open == isOpen())
return;
- KListViewItem::setOpen(open);
+ TDEListViewItem::setOpen(open);
fillColumns();
if(listView())
@@ -731,7 +731,7 @@ int KMyMoneyAccountTreeBaseItem::compare(TQListViewItem* i, int col, bool ascend
}
}
// do standard sorting here
- return KListViewItem::compare(i, col, ascending);
+ return TDEListViewItem::compare(i, col, ascending);
}
void KMyMoneyAccountTreeBaseItem::paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align)
@@ -800,7 +800,7 @@ void KMyMoneyAccountTreeBase::slotActivateSort(void)
{
--m_queuedSort;
if(!m_queuedSort)
- KListView::sort();
+ TDEListView::sort();
}
void KMyMoneyAccountTreeBaseItem::setNegative(bool isNegative)
@@ -817,7 +817,7 @@ void KMyMoneyAccountTreeBaseItem::setText( int column, const TQString &text, con
m_columnsColor[column] = TQColorGroup::Text;
}
- KListViewItem::setText(column, text);
+ TDEListViewItem::setText(column, text);
}
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebudget.cpp b/kmymoney2/widgets/kmymoneyaccounttreebudget.cpp
index 2038116..eb56496 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebudget.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreebudget.cpp
@@ -37,7 +37,7 @@ void KMyMoneyAccountTreeBudget::slotSelectObject(const TQListViewItem* i)
}
}
-KMyMoneyAccountTreeBudgetItem::KMyMoneyAccountTreeBudgetItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security, const TQString& name) :
+KMyMoneyAccountTreeBudgetItem::KMyMoneyAccountTreeBudgetItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security, const TQString& name) :
KMyMoneyAccountTreeBaseItem(parent, account, security, name),
m_budget(budget)
{
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp b/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
index d0903d2..ec198d6 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.cpp
@@ -156,7 +156,7 @@ void KMyMoneyAccountTreeForecast::slotSelectObject(const TQListViewItem* i)
}
}
-KMyMoneyAccountTreeForecastItem::KMyMoneyAccountTreeForecastItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security, const TQString& name) :
+KMyMoneyAccountTreeForecastItem::KMyMoneyAccountTreeForecastItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security, const TQString& name) :
KMyMoneyAccountTreeBaseItem(parent, account, security, name),
m_forecast(forecast)
{
diff --git a/kmymoney2/widgets/kmymoneycalendar.cpp b/kmymoney2/widgets/kmymoneycalendar.cpp
index 35d4599..2deeaf2 100644
--- a/kmymoney2/widgets/kmymoneycalendar.cpp
+++ b/kmymoney2/widgets/kmymoneycalendar.cpp
@@ -119,7 +119,7 @@ void kMyMoneyCalendar::init( const TQDate &dt )
d->selectWeek = new TQToolButton( this );
// KIconLoader *kiconloader = TDEGlobal::iconLoader();
- KPopupMenu* kpopupmenuNew = new KPopupMenu(this);
+ TDEPopupMenu* kpopupmenuNew = new TDEPopupMenu(this);
kpopupmenuNew->insertItem(i18n("Week"), this, TQT_SLOT(slotSetStyleWeekly()));
kpopupmenuNew->insertItem(i18n("Month"), this, TQT_SLOT(slotSetStyleMonthly()));
/* kpopupmenuNew->insertItem(i18n("3 Months"), this, TQT_SLOT(slotSetStyleQuarterly())); */
@@ -338,7 +338,7 @@ kMyMoneyCalendar::selectWeekClicked()
{
#if TDE_VERSION >= 310 && TDE_VERSION <= 314
int week;
- KPopupFrame* popup = new KPopupFrame(this);
+ TDEPopupFrame* popup = new TDEPopupFrame(this);
KDateInternalWeekSelector* picker = new KDateInternalWeekSelector(/*fontsize, */popup);
// -----
picker->resize(picker->sizeHint());
@@ -377,7 +377,7 @@ kMyMoneyCalendar::selectMonthClicked()
{
#if TDE_VERSION >= 310 && TDE_VERSION <= 314
int month;
- KPopupFrame* popup = new KPopupFrame(this);
+ TDEPopupFrame* popup = new TDEPopupFrame(this);
KDateInternalMonthPicker* picker = new KDateInternalMonthPicker(/*fontsize, */popup);
// -----
picker->resize(picker->sizeHint());
@@ -409,7 +409,7 @@ kMyMoneyCalendar::selectYearClicked()
{
#if TDE_VERSION >= 310 && TDE_VERSION <= 314
int year;
- KPopupFrame* popup = new KPopupFrame(this);
+ TDEPopupFrame* popup = new TDEPopupFrame(this);
KDateInternalYearSelector* picker = new KDateInternalYearSelector(fontsize, popup);
// -----
picker->resize(picker->sizeHint());
diff --git a/kmymoney2/widgets/kmymoneychecklistitem.cpp b/kmymoney2/widgets/kmymoneychecklistitem.cpp
index 49b96fa..b292567 100644
--- a/kmymoney2/widgets/kmymoneychecklistitem.cpp
+++ b/kmymoney2/widgets/kmymoneychecklistitem.cpp
@@ -105,7 +105,7 @@ const TQColor KMyMoneyCheckListItem::backgroundColor()
bool KMyMoneyCheckListItem::isAlternate(void)
{
-// logic taken from KListViewItem::isAlternate()
+// logic taken from TDEListViewItem::isAlternate()
KMyMoneyCheckListItem* ciAbove;
KMyMoneyListViewItem* liAbove;
ciAbove = dynamic_cast<KMyMoneyCheckListItem*> (itemAbove());
diff --git a/kmymoney2/widgets/kmymoneychecklistitem.h b/kmymoney2/widgets/kmymoneychecklistitem.h
index bb91b6a..1c5474d 100644
--- a/kmymoney2/widgets/kmymoneychecklistitem.h
+++ b/kmymoney2/widgets/kmymoneychecklistitem.h
@@ -64,7 +64,7 @@ public:
const TQColor backgroundColor();
/**
- * see KListViewItem::isAlternate()
+ * see TDEListViewItem::isAlternate()
*/
bool isAlternate(void);
@@ -85,7 +85,7 @@ protected:
private:
TQString m_key;
TQString m_id;
- // copied from KListViewItem()
+ // copied from TDEListViewItem()
unsigned int m_isOdd : 1;
unsigned int m_isKnown : 1;
unsigned int m_unused : 30;
diff --git a/kmymoney2/widgets/kmymoneycompletion.cpp b/kmymoney2/widgets/kmymoneycompletion.cpp
index 41fa082..0a7e99d 100644
--- a/kmymoney2/widgets/kmymoneycompletion.cpp
+++ b/kmymoney2/widgets/kmymoneycompletion.cpp
@@ -52,7 +52,7 @@ kMyMoneyCompletion::kMyMoneyCompletion(TQWidget *parent, const char *name ) :
connectSignals(m_selector, m_selector->listView());
}
-void kMyMoneyCompletion::connectSignals(TQWidget* widget, KListView* lv)
+void kMyMoneyCompletion::connectSignals(TQWidget* widget, TDEListView* lv)
{
m_widget = widget;
m_lv = lv;
diff --git a/kmymoney2/widgets/kmymoneycompletion.h b/kmymoney2/widgets/kmymoneycompletion.h
index 36ff70b..63a290e 100644
--- a/kmymoney2/widgets/kmymoneycompletion.h
+++ b/kmymoney2/widgets/kmymoneycompletion.h
@@ -34,7 +34,7 @@ class TQListViewItem;
// ----------------------------------------------------------------------------
// KDE Includes
-class KListView;
+class TDEListView;
// ----------------------------------------------------------------------------
// Project Includes
@@ -101,7 +101,7 @@ protected:
*/
void adjustSize(void);
- void connectSignals(TQWidget *widget, KListView* lv);
+ void connectSignals(TQWidget *widget, TDEListView* lv);
void show(bool presetSelected);
@@ -112,7 +112,7 @@ protected:
TQWidget* m_parent;
TQWidget* m_widget;
TQString m_id;
- KListView* m_lv;
+ TDEListView* m_lv;
KMyMoneySelector* m_selector;
TQRegExp m_lastCompletion;
diff --git a/kmymoney2/widgets/kmymoneydateinput.cpp b/kmymoney2/widgets/kmymoneydateinput.cpp
index bf64859..b2aecf2 100644
--- a/kmymoney2/widgets/kmymoneydateinput.cpp
+++ b/kmymoney2/widgets/kmymoneydateinput.cpp
@@ -241,7 +241,7 @@ void kMyMoneyDateInput::resizeEvent(TQResizeEvent* ev)
*/
void kMyMoneyDateInput::keyPressEvent(TQKeyEvent * k)
{
- KShortcut today(i18n("Enter todays date into date input widget", "T"));
+ TDEShortcut today(i18n("Enter todays date into date input widget", "T"));
switch(k->key()) {
case Key_Equal:
diff --git a/kmymoney2/widgets/kmymoneyforecastlistviewitem.cpp b/kmymoney2/widgets/kmymoneyforecastlistviewitem.cpp
index 9164d1a..deb3561 100644
--- a/kmymoney2/widgets/kmymoneyforecastlistviewitem.cpp
+++ b/kmymoney2/widgets/kmymoneyforecastlistviewitem.cpp
@@ -34,7 +34,7 @@
#include <kmymoney/kmymoneyglobalsettings.h>
KMyMoneyForecastListViewItem::KMyMoneyForecastListViewItem (TQListView* parent, TQListViewItem* after, bool isNegative) :
- KListViewItem(parent, after),
+ TDEListViewItem(parent, after),
m_negative(isNegative)
{
}
@@ -54,7 +54,7 @@ void KMyMoneyForecastListViewItem::paintCell(TQPainter *p, const TQColorGroup &c
}
_cg.setColor(TQColorGroup::Text, textColour);
- KListViewItem::paintCell(p, _cg, column, width, alignment);
+ TDEListViewItem::paintCell(p, _cg, column, width, alignment);
}
void KMyMoneyForecastListViewItem::setNegative(bool isNegative)
@@ -71,5 +71,5 @@ void KMyMoneyForecastListViewItem::setText( int column, const TQString &text, co
m_columnsColor[column] = TQColorGroup::Text;
}
- KListViewItem::setText(column, text);
+ TDEListViewItem::setText(column, text);
}
diff --git a/kmymoney2/widgets/kmymoneylistviewitem.h b/kmymoney2/widgets/kmymoneylistviewitem.h
index 5322ea6..984a4bc 100644
--- a/kmymoney2/widgets/kmymoneylistviewitem.h
+++ b/kmymoney2/widgets/kmymoneylistviewitem.h
@@ -39,7 +39,7 @@ class KMyMoneyCheckListItem;
*
* @author Thomas Baumgart
*/
-class KMyMoneyListViewItem : public TQObject, public KListViewItem
+class KMyMoneyListViewItem : public TQObject, public TDEListViewItem
{
friend class KMyMoneyCheckListItem;
@@ -79,7 +79,7 @@ public:
private:
TQString m_key;
TQString m_id;
- // copied from KListViewItem()
+ // copied from TDEListViewItem()
unsigned int m_isOdd : 1;
unsigned int m_isKnown : 1;
unsigned int m_unused : 30;
diff --git a/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui b/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
index 88f95f7..80fe7bd 100644
--- a/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
+++ b/kmymoney2/widgets/kmymoneyonlinequoteconfigdecl.ui
@@ -25,7 +25,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Name</string>
diff --git a/kmymoney2/widgets/kmymoneypriceview.cpp b/kmymoney2/widgets/kmymoneypriceview.cpp
index e1dd25e..8af269f 100644
--- a/kmymoney2/widgets/kmymoneypriceview.cpp
+++ b/kmymoney2/widgets/kmymoneypriceview.cpp
@@ -61,7 +61,7 @@
#define PRICE_COL 3
#define SOURCE_COL 4
-KMyMoneyPriceItem::KMyMoneyPriceItem(KListView *view, const MyMoneyPrice& pr) :
+KMyMoneyPriceItem::KMyMoneyPriceItem(TDEListView *view, const MyMoneyPrice& pr) :
KMyMoneyListViewItem(view, TQString(), TQString(), TQString()),
m_pr(pr)
{
@@ -119,7 +119,7 @@ int KMyMoneyPriceItem::compare(TQListViewItem* i, int col, bool ascending) const
}
KMyMoneyPriceView::KMyMoneyPriceView(TQWidget *parent, const char *name ) :
- KListView(parent,name),
+ TDEListView(parent,name),
m_contextMenu(0),
m_showAll(false)
{
@@ -139,7 +139,7 @@ KMyMoneyPriceView::KMyMoneyPriceView(TQWidget *parent, const char *name ) :
KIconLoader *kiconloader = TDEGlobal::iconLoader();
- m_contextMenu = new KPopupMenu(this);
+ m_contextMenu = new TDEPopupMenu(this);
m_contextMenu->insertTitle(i18n("Price Options"));
m_contextMenu->insertItem(kiconloader->loadIcon("filenew", KIcon::Small),
i18n("New..."),
@@ -220,7 +220,7 @@ void KMyMoneyPriceView::resizeEvent(TQResizeEvent* e)
setColumnWidth(4, w);
resizeContents(visibleWidth(), contentsHeight());
- KListView::resizeEvent(e);
+ TDEListView::resizeEvent(e);
}
void KMyMoneyPriceView::slotListClicked(TQListViewItem* item, const TQPoint&, int)
diff --git a/kmymoney2/widgets/kmymoneypriceview.h b/kmymoney2/widgets/kmymoneypriceview.h
index 979a003..4415b88 100644
--- a/kmymoney2/widgets/kmymoneypriceview.h
+++ b/kmymoney2/widgets/kmymoneypriceview.h
@@ -44,7 +44,7 @@
class KMyMoneyPriceItem : public KMyMoneyListViewItem
{
public:
- KMyMoneyPriceItem(KListView *, const MyMoneyPrice& pr);
+ KMyMoneyPriceItem(TDEListView *, const MyMoneyPrice& pr);
~KMyMoneyPriceItem() {}
int compare(TQListViewItem *p, int col, bool ascending) const;
@@ -56,7 +56,7 @@ private:
};
-class KMyMoneyPriceView : public KListView
+class KMyMoneyPriceView : public TDEListView
{
Q_OBJECT
@@ -81,7 +81,7 @@ signals:
void onlinePriceUpdate(void);
private:
- KPopupMenu* m_contextMenu;
+ TDEPopupMenu* m_contextMenu;
bool m_showAll;
};
diff --git a/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp b/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
index 9f6d131..8e8cf32 100644
--- a/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
+++ b/kmymoney2/widgets/kmymoneyscheduledcalendar.cpp
@@ -41,7 +41,7 @@ kMyMoneyScheduledCalendar::kMyMoneyScheduledCalendar(TQWidget *parent, const cha
{
TQPushButton *pb1 = new TQPushButton(i18n("Select Schedules"), this);
- kpopupmenu = new KPopupMenu(this);
+ kpopupmenu = new TDEPopupMenu(this);
kpopupmenu->setCheckable(true);
kpopupmenu->insertItem(i18n("Bills"), 0);
kpopupmenu->insertItem(i18n("Deposits"), 1);
diff --git a/kmymoney2/widgets/kmymoneyscheduledcalendar.h b/kmymoney2/widgets/kmymoneyscheduledcalendar.h
index d018518..682603c 100644
--- a/kmymoney2/widgets/kmymoneyscheduledcalendar.h
+++ b/kmymoney2/widgets/kmymoneyscheduledcalendar.h
@@ -35,7 +35,7 @@
#include "../widgets/kmymoneycalendar.h"
#include "../widgets/kmymoneyscheduleddatetbl.h"
-class KPopupMenu;
+class TDEPopupMenu;
class kMyMoneyDateTbl;
/**
@@ -81,7 +81,7 @@ protected slots:
void slotSetViewTransfers();
private:
- KPopupMenu* kpopupmenu;
+ TDEPopupMenu* kpopupmenu;
kMyMoneyScheduledDateTbl *m_scheduledDateTable;
};
diff --git a/kmymoney2/widgets/kmymoneyselector.cpp b/kmymoney2/widgets/kmymoneyselector.cpp
index 4f8af45..44fc546 100644
--- a/kmymoney2/widgets/kmymoneyselector.cpp
+++ b/kmymoney2/widgets/kmymoneyselector.cpp
@@ -41,7 +41,7 @@ KMyMoneySelector::KMyMoneySelector(TQWidget *parent, const char *name, TQWidget:
{
m_selMode = TQListView::Single;
- m_listView = new KListView(this);
+ m_listView = new TDEListView(this);
// don't show horizontal scroll bar
m_listView->setHScrollBarMode(TQScrollView::AlwaysOff);
diff --git a/kmymoney2/widgets/registersearchline.h b/kmymoney2/widgets/registersearchline.h
index 6c3a681..07568c7 100644
--- a/kmymoney2/widgets/registersearchline.h
+++ b/kmymoney2/widgets/registersearchline.h
@@ -39,7 +39,7 @@ namespace KMyMoneyRegister {
/**
* This class makes it easy to add a search line for filtering the items
* in a register based on simple text. Inspired by the idea of the tdelibs
- * class KListViewSearchLine.
+ * class TDEListViewSearchLine.
*
* @author Thomas Baumgart
*/
@@ -103,7 +103,7 @@ private:
/**
* Creates a widget containing a RegisterSearchLine, a label with the text
- * "Search" and a button to clear the search. Modelled after KListViewSearchLineWidget.
+ * "Search" and a button to clear the search. Modelled after TDEListViewSearchLineWidget.
*
* @author Thomas Baumgart
*/
diff --git a/kmymoney2/widgets/sortoptionlistitem.h b/kmymoney2/widgets/sortoptionlistitem.h
index 9276b16..39fc608 100644
--- a/kmymoney2/widgets/sortoptionlistitem.h
+++ b/kmymoney2/widgets/sortoptionlistitem.h
@@ -346,7 +346,7 @@ static const char * sortDescendingXpm[] = {
" e.f.g.h.i.j.k.l. ",
" m.n. "};
-class SortOptionListItem : public KListViewItem
+class SortOptionListItem : public TDEListViewItem
{
public:
SortOptionListItem(TQListView* parent, TQListViewItem* after, const TQString& txt, int direction);
@@ -363,7 +363,7 @@ private:
};
SortOptionListItem::SortOptionListItem(TQListView* parent, TQListViewItem* after, const TQString& txt, int direction) :
- KListViewItem(parent, after, txt)
+ TDEListViewItem(parent, after, txt)
{
m_direction = (direction >= 0) ? 1 : -1;
setPixmap();
@@ -372,9 +372,9 @@ SortOptionListItem::SortOptionListItem(TQListView* parent, TQListViewItem* after
void SortOptionListItem::setPixmap(void)
{
if(m_direction > 0)
- KListViewItem::setPixmap(0, TQPixmap(&sortAscendingXpm[0]));
+ TDEListViewItem::setPixmap(0, TQPixmap(&sortAscendingXpm[0]));
else
- KListViewItem::setPixmap(0, TQPixmap(&sortDescendingXpm[0]));
+ TDEListViewItem::setPixmap(0, TQPixmap(&sortDescendingXpm[0]));
}
void SortOptionListItem::toggleDirection(void)
diff --git a/kmymoney2/widgets/transactionsortoption.ui b/kmymoney2/widgets/transactionsortoption.ui
index 393e0bc..2a677ba 100644
--- a/kmymoney2/widgets/transactionsortoption.ui
+++ b/kmymoney2/widgets/transactionsortoption.ui
@@ -28,7 +28,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Sort options</string>
@@ -123,7 +123,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Sort order</string>
@@ -283,7 +283,7 @@
</Q_SLOTS>
<functions>
<function specifier="non virtual">init()</function>
- <function access="protected" specifier="non virtual" returnType="TQListViewItem *">addEntry( KListView * p, TQListViewItem * after, int idx )</function>
+ <function access="protected" specifier="non virtual" returnType="TQListViewItem *">addEntry( TDEListView * p, TQListViewItem * after, int idx )</function>
<function specifier="non virtual" returnType="TQString">settings( void ) const</function>
</functions>
<layoutdefaults spacing="6" margin="11"/>
diff --git a/kmymoney2/widgets/transactionsortoption.ui.h b/kmymoney2/widgets/transactionsortoption.ui.h
index cf87646..2a1f2e2 100644
--- a/kmymoney2/widgets/transactionsortoption.ui.h
+++ b/kmymoney2/widgets/transactionsortoption.ui.h
@@ -106,7 +106,7 @@ void TransactionSortOption::setSettings(const TQString& settings)
}
}
-TQListViewItem* TransactionSortOption::addEntry( KListView * p, TQListViewItem* after, int idx )
+TQListViewItem* TransactionSortOption::addEntry( TDEListView * p, TQListViewItem* after, int idx )
{
TQString txt = KMyMoneyRegister::sortOrderToText(static_cast<KMyMoneyRegister::TransactionSortField>(abs(idx)));
if(txt.isEmpty())
diff --git a/kmymoney2/widgets/klistviewsearchline.h b/kmymoney2/widgets/klistviewsearchline.h
index 28aeaef..2ffad3c 100644
--- a/kmymoney2/widgets/klistviewsearchline.h
+++ b/kmymoney2/widgets/klistviewsearchline.h
@@ -24,7 +24,7 @@
#include <tqhbox.h>
#include <kmymoney/export.h>
-class KListView;
+class TDEListView;
class TQListViewItem;
class TQToolButton;
@@ -33,12 +33,12 @@ class TQToolButton;
* listview based on a simple text search.
*
* No changes to the application other than instantiating this class with an
* appropriate KListView should be needed.
*
* @since 3.3
*/
-class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
+class KMYMONEY_EXPORT TDEListViewSearchLine : public KLineEdit
{
Q_OBJECT
@@ -46,24 +46,24 @@ class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
public:
/**
* Constructs a KListViewSearchLine with \a listView being the KListView to
* be filtered.
*
* If \a listView is null then the widget will be disabled until a listview
* is set with setListView().
*/
- KListViewSearchLine(TQWidget *parent = 0, KListView *listView = 0, const char *name = 0);
+ TDEListViewSearchLine(TQWidget *parent = 0, TDEListView *listView = 0, const char *name = 0);
/**
* Constructs a KListViewSearchLine without any KListView to filter. The
* KListView object has to be set later with setListView().
*/
- KListViewSearchLine(TQWidget *parent, const char *name);
+ TDEListViewSearchLine(TQWidget *parent, const char *name);
/**
* Destroys the KListViewSearchLine.
*/
- virtual ~KListViewSearchLine();
+ virtual ~TDEListViewSearchLine();
/**
* Returns true if the search is case sensitive. This defaults to false.
@@ -93,7 +93,7 @@ public:
*
* @see setListView()
*/
- KListView *listView() const;
+ TDEListView *listView() const;
public slots:
/**
@@ -131,12 +131,12 @@ public slots:
void setSearchColumns(const TQValueList<int> &columns);
/**
* Sets the KListView that is filtered by this search line. If \a lv is null
* then the widget will be disabled.
*
* @see listView()
*/
- void setListView(KListView *lv);
+ void setListView(TDEListView *lv);
protected:
@@ -201,44 +201,44 @@ private slots:
void searchColumnsMenuActivated(int);
private:
- class KListViewSearchLinePrivate;
- KListViewSearchLinePrivate *d;
+ class TDEListViewSearchLinePrivate;
+ TDEListViewSearchLinePrivate *d;
};
/**
* Creates a widget featuring a KListViewSearchLine, a label with the text
* "Search" and a button to clear the search.
*
* @since 3.4
*/
-class KMYMONEY_EXPORT KListViewSearchLineWidget : public TQHBox
+class KMYMONEY_EXPORT TDEListViewSearchLineWidget : public TQHBox
{
Q_OBJECT
public:
/**
* Creates a KListViewSearchLineWidget for \a listView with \a parent as the
* parent with and \a name.
*/
- KListViewSearchLineWidget(KListView *listView = 0, TQWidget *parent = 0,
+ TDEListViewSearchLineWidget(TDEListView *listView = 0, TQWidget *parent = 0,
const char *name = 0);
/**
* Destroys the KListViewSearchLineWidget
*/
- ~KListViewSearchLineWidget();
+ ~TDEListViewSearchLineWidget();
/**
* Creates the search line. This can be useful to reimplement in cases where
* a KListViewSearchLine subclass is used.
*/
- virtual KListViewSearchLine *createSearchLine(KListView *listView);
+ virtual TDEListViewSearchLine *createSearchLine(TDEListView *listView);
/**
* Returns a pointer to the search line.
*/
- KListViewSearchLine *searchLine() const;
+ TDEListViewSearchLine *searchLine() const;
protected slots:
/**
@@ -253,8 +253,8 @@ private slots:
void positionInToolBar();
private:
- class KListViewSearchLineWidgetPrivate;
- KListViewSearchLineWidgetPrivate *d;
+ class TDEListViewSearchLineWidgetPrivate;
+ TDEListViewSearchLineWidgetPrivate *d;
};
#endif
@@ -33,12 +33,12 @@ class TQToolButton;
*
* No changes to the application other than instantiating this class with an
- * appropriate KListView should be needed.
+ * appropriate TDEListView should be needed.
*
* @since 3.3
@@ -46,24 +46,24 @@ class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
public:
/**
- * Constructs a KListViewSearchLine with \a listView being the KListView to
+ * Constructs a TDEListViewSearchLine with \a listView being the TDEListView to
* be filtered.
*
@@ -46,24 +46,24 @@ class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
/**
- * Constructs a KListViewSearchLine without any KListView to filter. The
- * KListView object has to be set later with setListView().
+ * Constructs a TDEListViewSearchLine without any TDEListView to filter. The
+ * TDEListView object has to be set later with setListView().
*/
@@ -46,24 +46,24 @@ class KMYMONEY_EXPORT KListViewSearchLine : public KLineEdit
/**
- * Destroys the KListViewSearchLine.
+ * Destroys the TDEListViewSearchLine.
*/
@@ -131,12 +131,12 @@ public slots:
void setSearchColumns(const TQValueList<int> &columns);
/**
- * Sets the KListView that is filtered by this search line. If \a lv is null
+ * Sets the TDEListView that is filtered by this search line. If \a lv is null
* then the widget will be disabled.
*
@@ -201,44 +201,44 @@ private slots:
};
/**
- * Creates a widget featuring a KListViewSearchLine, a label with the text
+ * Creates a widget featuring a TDEListViewSearchLine, a label with the text
* "Search" and a button to clear the search.
*
@@ -201,44 +201,44 @@ private slots:
public:
/**
- * Creates a KListViewSearchLineWidget for \a listView with \a parent as the
+ * Creates a TDEListViewSearchLineWidget for \a listView with \a parent as the
* parent with and \a name.
*/
@@ -201,44 +201,44 @@ private slots:
const char *name = 0);
/**
- * Destroys the KListViewSearchLineWidget
+ * Destroys the TDEListViewSearchLineWidget
*/
@@ -201,44 +201,44 @@ private slots:
/**
* Creates the search line. This can be useful to reimplement in cases where
- * a KListViewSearchLine subclass is used.
+ * a TDEListViewSearchLine subclass is used.
*/
diff --git a/kmymoney2/widgets/kmymoneyaccounttree.h b/kmymoney2/widgets/kmymoneyaccounttree.h
index c879fef..9b808b3 100644
--- a/kmymoney2/widgets/kmymoneyaccounttree.h
+++ b/kmymoney2/widgets/kmymoneyaccounttree.h
@@ -43,27 +43,27 @@ public:
* Constructor to be used to construct an institution entry
* object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
* the KListView entry is constructed
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyInstitution& institution);
+ KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyInstitution& institution);
/**
* Constructor to be used to construct a standard account entry object (e.g. Asset,
* Liability, etc.).
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
/**
* Constructor to be used to construct an account entry
@@ -72,7 +72,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks
* @param security const reference to the security used to show the value. Usually
@@ -43,27 +43,27 @@ public:
* object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
@@ -43,27 +43,27 @@ public:
* added to.
* @param institution const reference to MyMoneyInstitution for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
*/
@@ -43,27 +43,27 @@ public:
* Liability, etc.).
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -43,27 +43,27 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
@@ -72,7 +72,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebase.h b/kmymoney2/widgets/kmymoneyaccounttreebase.h
index 5932f85..528c845 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebase.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreebase.h
@@ -40,7 +40,7 @@ class TQDragObject;
class KMyMoneyAccountTreeBaseItem;
-class KMyMoneyAccountTreeBase : public KListView
+class KMyMoneyAccountTreeBase : public TDEListView
{
friend class KMyMoneyAccountTreeBaseItem;
@@ -154,11 +154,11 @@ protected slots:
* and checks if the item pointed to by @p i is either an account or institution
* and sends out the necessary signal openContextMenu.
*
* @param lv pointer to KListView
* @param i pointer to TQListViewItem
* @param p position information
*/
- void slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p);
+ void slotOpenContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint& p);
/**
* This slot is connected to the accout list view's executed signal
@@ -174,7 +174,7 @@ protected slots:
/** Open the folder pointed to by m_dropItem */
void slotOpenFolder(void);
/** override KListView implementation */
void cleanItemHighlighter(void);
void slotActivateSort(void);
@@ -255,7 +255,7 @@ signals:
void reparent(const MyMoneyAccount& acc, const MyMoneyInstitution& institution);
};
-class KMyMoneyAccountTreeBaseItem : public KListViewItem
+class KMyMoneyAccountTreeBaseItem : public TDEListViewItem
{
public:
typedef enum {
@@ -267,27 +267,27 @@ public:
* Constructor to be used to construct an institution entry
* object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
* the KListView entry is constructed
*/
- KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyInstitution& institution);
+ KMyMoneyAccountTreeBaseItem(TDEListView *parent, const MyMoneyInstitution& institution);
/**
* Constructor to be used to construct a standard account entry object (e.g. Asset,
* Liability, etc.).
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeBaseItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
/**
* Constructor to be used to construct an account entry
@@ -296,7 +296,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks
* @param security const reference to the security used to show the value. Usually
@@ -356,7 +356,7 @@ public:
* o is FALSE, the children of this item are initially hidden.
* The user can show them by clicking the + icon to the left of the item.
*
* Overrides KListViewItem::setOpen() and exchanges the value field
* with either the value of this account and its subaccounts if @p o
* is false or the value of this account if @p o is true.
*
@@ -374,7 +374,7 @@ public:
/**
* Convenience method to return casted pointer
*/
- KMyMoneyAccountTreeBase* listView(void) const { return dynamic_cast<KMyMoneyAccountTreeBase*>(KListViewItem::listView()); };
+ KMyMoneyAccountTreeBase* listView(void) const { return dynamic_cast<KMyMoneyAccountTreeBase*>(TDEListViewItem::listView()); };
/**
* Return the type of entry
@@ -154,11 +154,11 @@ protected slots:
* and sends out the necessary signal openContextMenu.
*
- * @param lv pointer to KListView
+ * @param lv pointer to TDEListView
* @param i pointer to TQListViewItem
* @param p position information
@@ -174,7 +174,7 @@ protected slots:
/** Open the folder pointed to by m_dropItem */
void slotOpenFolder(void);
- /** override KListView implementation */
+ /** override TDEListView implementation */
void cleanItemHighlighter(void);
void slotActivateSort(void);
@@ -267,27 +267,27 @@ public:
* object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
@@ -267,27 +267,27 @@ public:
* added to.
* @param institution const reference to MyMoneyInstitution for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
*/
@@ -267,27 +267,27 @@ public:
* Liability, etc.).
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -267,27 +267,27 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
@@ -296,7 +296,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param price price to be used to calculate value (defaults to 1)
* This is used for accounts denominated in foreign currencies or stocks
@@ -356,7 +356,7 @@ public:
* The user can show them by clicking the + icon to the left of the item.
*
- * Overrides KListViewItem::setOpen() and exchanges the value field
+ * Overrides TDEListViewItem::setOpen() and exchanges the value field
* with either the value of this account and its subaccounts if @p o
* is false or the value of this account if @p o is true.
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebudget.h b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
index 1b5139a..6f3c244 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebudget.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
@@ -60,7 +60,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
* @param price price to be used to calculate value (defaults to 1)
@@ -77,7 +77,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
* @param security const reference to the security used to show the value. Usually
@@ -85,7 +85,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeBudgetItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeBudgetItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeBudgetItem();
@@ -60,7 +60,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
@@ -77,7 +77,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
index 8bde078..6965ab4 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
@@ -69,7 +69,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
* @param price price to be used to calculate value (defaults to 1)
@@ -86,7 +86,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
* @param security const reference to the security used to show the value. Usually
@@ -94,7 +94,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeForecastItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeForecastItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeForecastItem();
@@ -69,7 +69,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
@@ -86,7 +86,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
diff --git a/kmymoney2/widgets/kmymoneyforecastlistviewitem.h b/kmymoney2/widgets/kmymoneyforecastlistviewitem.h
index fe5fd0a..eb0eed1 100644
--- a/kmymoney2/widgets/kmymoneyforecastlistviewitem.h
+++ b/kmymoney2/widgets/kmymoneyforecastlistviewitem.h
@@ -32,12 +32,12 @@
// Project Includes
/**
* This class implements a derived version of a KListViewItem that
* allows printing negative numbers in red
*
* @author Alvaro Soliverez
*/
-class KMyMoneyForecastListViewItem : public KListViewItem
+class KMyMoneyForecastListViewItem : public TDEListViewItem
{
public:
@@ -32,12 +32,12 @@
// Project Includes
/**
- * This class implements a derived version of a KListViewItem that
+ * This class implements a derived version of a TDEListViewItem that
* allows printing negative numbers in red
*
diff --git a/kmymoney2/widgets/kmymoneylistviewitem.cpp b/kmymoney2/widgets/kmymoneylistviewitem.cpp
index 09ff2f9..9e71ba8 100644
--- a/kmymoney2/widgets/kmymoneylistviewitem.cpp
+++ b/kmymoney2/widgets/kmymoneylistviewitem.cpp
@@ -36,7 +36,7 @@
#include "../kmymoneyglobalsettings.h"
KMyMoneyListViewItem::KMyMoneyListViewItem(TQListView* parent, const TQString& txt, const TQString& key, const TQString& id) :
- KListViewItem(parent, txt),
+ TDEListViewItem(parent, txt),
m_key(key),
m_id(id),
m_isOdd(0),
@@ -47,7 +47,7 @@ KMyMoneyListViewItem::KMyMoneyListViewItem(TQListView* parent, const TQString& t
}
KMyMoneyListViewItem::KMyMoneyListViewItem(TQListViewItem* parent, const TQString& txt, const TQString& key, const TQString& id) :
- KListViewItem(parent, txt),
+ TDEListViewItem(parent, txt),
m_key(key),
m_id(id),
m_isOdd(0),
@@ -76,7 +76,7 @@ void KMyMoneyListViewItem::paintCell(TQPainter *p, const TQColorGroup &cg, int c
TQColorGroup _cg = cg;
_cg.setColor(TQColorGroup::Base, backgroundColor());
// make sure to bypass KListViewItem::paintCell() as
// we don't like it's logic - that's why we do this
// here ;-) (ipwizard)
TQListViewItem::paintCell(p, _cg, column, width, alignment);
@@ -89,7 +89,7 @@ const TQColor KMyMoneyListViewItem::backgroundColor()
bool KMyMoneyListViewItem::isAlternate(void)
{
// logic taken from KListViewItem::isAlternate()
KMyMoneyCheckListItem* ciAbove;
KMyMoneyListViewItem* liAbove;
ciAbove = dynamic_cast<KMyMoneyCheckListItem*> (itemAbove());
@@ -76,7 +76,7 @@ void KMyMoneyListViewItem::paintCell(TQPainter *p, const TQColorGroup &cg, int c
TQColorGroup _cg = cg;
_cg.setColor(TQColorGroup::Base, backgroundColor());
- // make sure to bypass KListViewItem::paintCell() as
+ // make sure to bypass TDEListViewItem::paintCell() as
// we don't like it's logic - that's why we do this
// here ;-) (ipwizard)
@@ -89,7 +89,7 @@ const TQColor KMyMoneyListViewItem::backgroundColor()
bool KMyMoneyListViewItem::isAlternate(void)
{
-// logic taken from KListViewItem::isAlternate()
+// logic taken from TDEListViewItem::isAlternate()
KMyMoneyCheckListItem* ciAbove;
KMyMoneyListViewItem* liAbove;
diff --git a/kmymoney2/widgets/kmymoneyselector.h b/kmymoney2/widgets/kmymoneyselector.h
index 0a4ac8b..f50e404 100644
--- a/kmymoney2/widgets/kmymoneyselector.h
+++ b/kmymoney2/widgets/kmymoneyselector.h
@@ -28,7 +28,7 @@ class TQHBoxLayout;
// ----------------------------------------------------------------------------
// KDE Includes
-class KListView;
+class TDEListView;
// ----------------------------------------------------------------------------
// Project Includes
@@ -137,9 +137,9 @@ public:
void setSelected(const TQString& id, const bool state = false);
/**
* Return a pointer to the KListView object
*/
- KListView* listView(void) const { return m_listView; };
+ TDEListView* listView(void) const { return m_listView; };
/**
* This method selects/deselects all items that
@@ -201,7 +201,7 @@ public:
/**
* This method creates a new selectable object depending on the
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode
*
* @note The new item will be the first one in the selection
@@ -217,7 +217,7 @@ public:
/**
* This method creates a new selectable object depending on the
* selection mode. This is either a KListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
* In contrast to the above method, the parent is always the view.
*
@@ -362,7 +362,7 @@ protected slots:
void slotShowSelected(void);
/**
* This slot is connected to the KListView executed signal
*/
void slotItemSelected(TQListViewItem *it_v);
@@ -375,7 +375,7 @@ protected slots:
void slotListRightMouse(TQListViewItem* it_v, const TQPoint& p, int /* col */);
protected:
- KListView* m_listView;
+ TDEListView* m_listView;
TQStringList m_itemList;
TQString m_baseName;
TQListView::SelectionMode m_selMode;
@@ -137,9 +137,9 @@ public:
void setSelected(const TQString& id, const bool state = false);
/**
- * Return a pointer to the KListView object
+ * Return a pointer to the TDEListView object
*/
@@ -201,7 +201,7 @@ public:
/**
* This method creates a new selectable object depending on the
- * selection mode. This is either a KListViewItem for single
+ * selection mode. This is either a TDEListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode
*
@@ -217,7 +217,7 @@ public:
/**
* This method creates a new selectable object depending on the
- * selection mode. This is either a KListViewItem for single
+ * selection mode. This is either a TDEListViewItem for single
* selection mode or a KMyMoneyCheckListItem for multi selection mode.
* In contrast to the above method, the parent is always the view.
@@ -362,7 +362,7 @@ protected slots:
void slotShowSelected(void);
/**
- * This slot is connected to the KListView executed signal
+ * This slot is connected to the TDEListView executed signal
*/
void slotItemSelected(TQListViewItem *it_v);